@@ -77,6 +77,7 @@ extern "C"
 
 // Local includes
 
+#include "config-digikam.h"
 #include "albumdb.h"
 #include "album.h"
 #include "albumsettings.h"
@@ -239,7 +240,7 @@ public:
         // build list
         foreach (const QFileInfo& info, fileInfoList)
         {
-            // ignore digikam4.db and journal and other temporary files
+            // ignore DIGIKAM4DB and journal and other temporary files
             if (!dirWatchBlackList.contains(info.fileName()))
             {
                 modList << info.lastModified();
@@ -308,8 +309,8 @@ AlbumManager::AlbumManager()
     internalInstance = this;
     d->dirWatch      = new KDirWatch(this);
 
-    connect(d->dirWatch, SIGNAL(dirty(const QString&)),
-            this, SLOT(slotDirWatchDirty(const QString&)));
+    connect(d->dirWatch, SIGNAL(dirty(QString)),
+            this, SLOT(slotDirWatchDirty(QString)));
 
     // these operations are pretty fast, no need for long queuing
     d->scanPAlbumsTimer = new QTimer(this);
@@ -405,16 +406,28 @@ void AlbumManager::cleanUp()
     }
 }
 
-bool AlbumManager::databaseEqual(const QString& dbType, const QString& dbName,
+bool AlbumManager::imgDatabaseEqual(const QString& dbType, const QString& dbName,
                                  const QString& dbHostName, int dbPort, bool dbInternalServer) const
 {
     DatabaseParameters params = DatabaseAccess::parameters();
 
-    return params.databaseType   == dbType          &&
-           params.databaseName   == dbName          &&
-           params.hostName       == dbHostName      &&
-           params.port           == dbPort          &&
+    return params.imgDatabaseType   == dbType          &&
+           params.imgDatabaseName   == dbName          &&
+           params.imgHostName       == dbHostName      &&
+           params.imgPort           == dbPort          &&
            params.internalServer == dbInternalServer;
+	   //FIXME: dbInternalServer
+}
+
+bool AlbumManager::tmbDatabaseEqual(const QString& dbType, const QString& dbName,
+                                 const QString& dbHostName, int dbPort) const
+{
+    DatabaseParameters params = DatabaseAccess::parameters();
+
+    return params.tmbDatabaseType   == dbType          &&
+           params.tmbDatabaseName   == dbName          &&
+           params.tmbHostName       == dbHostName      &&
+           params.tmbPort           == dbPort;
 }
 
 static bool moveToBackup(const QFileInfo& info)
@@ -465,7 +478,7 @@ void AlbumManager::checkDatabaseDirsAfterFirstRun(const QString& dbPath, const Q
     QDir               newDir(dbPath);
     QDir               albumDir(albumPath);
     DatabaseParameters newParams = DatabaseParameters::parametersForSQLiteDefaultFile(newDir.path());
-    QFileInfo          digikam4DB(newParams.SQLiteDatabaseFile());
+    QFileInfo          digikam4DB(newParams.imgSQLiteDatabaseFile());
 
     if (!digikam4DB.exists())
     {
@@ -510,10 +523,10 @@ void AlbumManager::changeDatabase(const DatabaseParameters& newParams)
     DatabaseParameters params = DatabaseAccess::parameters();
 
     // New database type SQLITE
-    if (newParams.isSQLite())
+    if (newParams.isImgSQLite())
     {
-        QDir newDir(newParams.getDatabaseNameOrDir());
-        QFileInfo newFile(newDir, QString("digikam4.db"));
+        QDir newDir(newParams.getImgDatabaseNameOrDir());
+        QFileInfo newFile(newDir, QString(DIGIKAM4DB));
 
         if (!newFile.exists())
         {
@@ -527,7 +540,7 @@ void AlbumManager::changeDatabase(const DatabaseParameters& newParams)
                 KGuiItem upgrade(i18n("Upgrade Database"), "view-refresh");
                 int result = -1;
 
-                if (params.isSQLite())
+                if (params.isImgSQLite())
                 {
                     result = KMessageBox::warningYesNoCancel(0,
                                                              i18n("<p>You have chosen the folder \"%1\" as the new place to store the database. "
@@ -566,7 +579,7 @@ void AlbumManager::changeDatabase(const DatabaseParameters& newParams)
                 else if (result == KMessageBox::Cancel)
                 {
                     QDir oldDir(d->dbName);
-                    QFileInfo oldFile(params.SQLiteDatabaseFile());
+                    QFileInfo oldFile(params.imgSQLiteDatabaseFile());
                     copyToNewLocation(oldFile, newFile, i18n("Failed to copy the old database file (\"%1\") "
                                                              "to its new location (\"%2\"). "
                                                              "Trying to upgrade old databases.",
@@ -577,7 +590,7 @@ void AlbumManager::changeDatabase(const DatabaseParameters& newParams)
             {
                 int result = KMessageBox::Yes;
 
-                if (params.isSQLite())
+                if (params.isImgSQLite())
                 {
                     KGuiItem copyCurrent(i18n("Copy Current Database"), "edit-copy");
                     KGuiItem startFresh(i18n("Create New Database"), "document-new");
@@ -593,7 +606,7 @@ void AlbumManager::changeDatabase(const DatabaseParameters& newParams)
                 if (result == KMessageBox::No)
                 {
                     QDir oldDir(d->dbName);
-                    QFileInfo oldFile(params.SQLiteDatabaseFile());
+                    QFileInfo oldFile(params.imgSQLiteDatabaseFile());
                     copyToNewLocation(oldFile, newFile);
                 }
             }
@@ -602,7 +615,7 @@ void AlbumManager::changeDatabase(const DatabaseParameters& newParams)
         {
             int result = KMessageBox::No;
 
-            if (params.isSQLite())
+            if (params.isImgSQLite())
             {
                 KGuiItem replaceItem(i18n("Copy Current Database"), "edit-copy");
                 KGuiItem useExistingItem(i18n("Use Existing File"), "document-open");
@@ -622,7 +635,7 @@ void AlbumManager::changeDatabase(const DatabaseParameters& newParams)
                 if (moveToBackup(newFile))
                 {
                     QDir oldDir(d->dbName);
-                    QFileInfo oldFile(params.SQLiteDatabaseFile());
+                    QFileInfo oldFile(params.imgSQLiteDatabaseFile());
 
                     // then copy
                     copyToNewLocation(oldFile, newFile);
@@ -905,7 +918,7 @@ bool AlbumManager::setDatabase(const DatabaseParameters& params, bool priority,
 
             for (int i=0; i<candidateIds.size(); ++i)
             {
-                migrateChoices->addItem(candidateDescriptions[i], candidateIds[i]);
+                migrateChoices->addItem(candidateDescriptions.at(i), candidateIds.at(i));
             }
 
             layout->addWidget(migrateButton,  0, 0, Qt::AlignTop);
@@ -986,9 +999,9 @@ bool AlbumManager::setDatabase(const DatabaseParameters& params, bool priority,
 #ifdef USE_THUMBS_DB
     QApplication::setOverrideCursor(Qt::WaitCursor);
 
-    if (params.isSQLite())
+    if (params.isTmbSQLite())
     {
-        d->dirWatchBlackList << "thumbnails-digikam.db" << "thumbnails-digikam.db-journal";
+        d->dirWatchBlackList << THUMBNAILS_DIGIKAMDB << "thumbnails-digikam.db-journal";
     }
 
     ThumbnailLoadThread::initializeThumbnailDatabase(DatabaseAccess::parameters().thumbnailParameters(),
@@ -1003,9 +1016,9 @@ bool AlbumManager::setDatabase(const DatabaseParameters& params, bool priority,
     // -- ---------------------------------------------------------
 
     // measures to filter out KDirWatch signals caused by database operations
-    if (params.isSQLite())
+    if (params.isImgSQLite())
     {
-        QFileInfo dbFile(params.SQLiteDatabaseFile());
+        QFileInfo dbFile(params.imgSQLiteDatabaseFile());
         d->dirWatchBlackList << dbFile.fileName() << dbFile.fileName() + "-journal";
 
         // ensure this is done after setting up the black list
@@ -1071,7 +1084,7 @@ bool AlbumManager::checkNepomukService()
 /*
     QEventLoop loop;
 
-    if (!connect(&nepomukInterface, SIGNAL(serviceInitialized(const QString &)),
+    if (!connect(&nepomukInterface, SIGNAL(serviceInitialized(QString)),
                  &loop, SLOT(quit())))
     {
         kDebug() << "Could not connect to Nepomuk server signal";
@@ -1125,11 +1138,11 @@ void AlbumManager::startScan()
     // connect to KDirNotify
 
     QDBusConnection::sessionBus().connect(QString(), QString(), "org.kde.KDirNotify", "FileMoved",
-                                          this, SLOT(slotKioFileMoved(const QString&, const QString&)));
+                                          this, SLOT(slotKioFileMoved(QString,QString)));
     QDBusConnection::sessionBus().connect(QString(), QString(), "org.kde.KDirNotify", "FilesAdded",
-                                          this, SLOT(slotKioFilesAdded(const QString&)));
+                                          this, SLOT(slotKioFilesAdded(QString)));
     QDBusConnection::sessionBus().connect(QString(), QString(), "org.kde.KDirNotify", "FilesRemoved",
-                                          this, SLOT(slotKioFilesDeleted(const QStringList&)));
+                                          this, SLOT(slotKioFilesDeleted(QStringList)));
 
     // create root albums
     d->rootPAlbum = new PAlbum(i18n("My Albums"));
@@ -1156,31 +1169,31 @@ void AlbumManager::startScan()
     }
 
     // listen to location status changes
-    connect(CollectionManager::instance(), SIGNAL(locationStatusChanged(const CollectionLocation&, int)),
-            this, SLOT(slotCollectionLocationStatusChanged(const CollectionLocation&, int)));
+    connect(CollectionManager::instance(), SIGNAL(locationStatusChanged(CollectionLocation,int)),
+            this, SLOT(slotCollectionLocationStatusChanged(CollectionLocation,int)));
 
-    connect(CollectionManager::instance(), SIGNAL(locationPropertiesChanged(const CollectionLocation&)),
-            this, SLOT(slotCollectionLocationPropertiesChanged(const CollectionLocation&)));
+    connect(CollectionManager::instance(), SIGNAL(locationPropertiesChanged(CollectionLocation)),
+            this, SLOT(slotCollectionLocationPropertiesChanged(CollectionLocation)));
 
     // reload albums
     refresh();
 
     // listen to album database changes
-    connect(DatabaseAccess::databaseWatch(), SIGNAL(albumChange(const AlbumChangeset&)),
-            this, SLOT(slotAlbumChange(const AlbumChangeset&)));
+    connect(DatabaseAccess::databaseWatch(), SIGNAL(albumChange(AlbumChangeset)),
+            this, SLOT(slotAlbumChange(AlbumChangeset)));
 
-    connect(DatabaseAccess::databaseWatch(), SIGNAL(tagChange(const TagChangeset&)),
-            this, SLOT(slotTagChange(const TagChangeset&)));
+    connect(DatabaseAccess::databaseWatch(), SIGNAL(tagChange(TagChangeset)),
+            this, SLOT(slotTagChange(TagChangeset)));
 
-    connect(DatabaseAccess::databaseWatch(), SIGNAL(searchChange(const SearchChangeset&)),
-            this, SLOT(slotSearchChange(const SearchChangeset&)));
+    connect(DatabaseAccess::databaseWatch(), SIGNAL(searchChange(SearchChangeset)),
+            this, SLOT(slotSearchChange(SearchChangeset)));
 
     // listen to collection image changes
-    connect(DatabaseAccess::databaseWatch(), SIGNAL(collectionImageChange(const CollectionImageChangeset&)),
-            this, SLOT(slotCollectionImageChange(const CollectionImageChangeset&)));
+    connect(DatabaseAccess::databaseWatch(), SIGNAL(collectionImageChange(CollectionImageChangeset)),
+            this, SLOT(slotCollectionImageChange(CollectionImageChangeset)));
 
-    connect(DatabaseAccess::databaseWatch(), SIGNAL(imageTagChange(const ImageTagChangeset&)),
-            this, SLOT(slotImageTagChange(const ImageTagChangeset&)));
+    connect(DatabaseAccess::databaseWatch(), SIGNAL(imageTagChange(ImageTagChangeset)),
+            this, SLOT(slotImageTagChange(ImageTagChangeset)));
 
     emit signalAllAlbumsLoaded();
 }
@@ -1525,8 +1538,8 @@ void AlbumManager::getAlbumItemsCount()
     connect(d->albumListJob, SIGNAL(result(KJob*)),
             this, SLOT(slotAlbumsJobResult(KJob*)));
 
-    connect(d->albumListJob, SIGNAL(data(KIO::Job*, const QByteArray&)),
-            this, SLOT(slotAlbumsJobData(KIO::Job*, const QByteArray&)));
+    connect(d->albumListJob, SIGNAL(data(KIO::Job*,QByteArray)),
+            this, SLOT(slotAlbumsJobData(KIO::Job*,QByteArray)));
 }
 
 void AlbumManager::scanTAlbums()
@@ -1648,7 +1661,7 @@ void AlbumManager::scanTAlbums()
         }
 
         // Its a new album. Find the parent of the album
-        TagMap::iterator iter = tmap.find(info.pid);
+        TagMap::const_iterator iter = tmap.constFind(info.pid);
 
         if (iter == tmap.end())
         {
@@ -1702,8 +1715,8 @@ void AlbumManager::getTagItemsCount()
     connect(d->tagListJob, SIGNAL(result(KJob*)),
             this, SLOT(slotTagsJobResult(KJob*)));
 
-    connect(d->tagListJob, SIGNAL(data(KIO::Job*, const QByteArray&)),
-            this, SLOT(slotTagsJobData(KIO::Job*, const QByteArray&)));
+    connect(d->tagListJob, SIGNAL(data(KIO::Job*,QByteArray)),
+            this, SLOT(slotTagsJobData(KIO::Job*,QByteArray)));
 
     if (d->personListJob)
     {
@@ -1717,8 +1730,8 @@ void AlbumManager::getTagItemsCount()
     connect(d->personListJob, SIGNAL(result(KJob*)),
             this, SLOT(slotPeopleJobResult(KJob*)));
 
-    connect(d->personListJob, SIGNAL(data(KIO::Job*, const QByteArray&)),
-            this, SLOT(slotPeopleJobData(KIO::Job*, const QByteArray&)));
+    connect(d->personListJob, SIGNAL(data(KIO::Job*,QByteArray)),
+            this, SLOT(slotPeopleJobData(KIO::Job*,QByteArray)));
 }
 
 void AlbumManager::scanSAlbums()
@@ -1818,8 +1831,8 @@ void AlbumManager::scanDAlbums()
     connect(d->dateListJob, SIGNAL(result(KJob*)),
             this, SLOT(slotDatesJobResult(KJob*)));
 
-    connect(d->dateListJob, SIGNAL(data(KIO::Job*, const QByteArray&)),
-            this, SLOT(slotDatesJobData(KIO::Job*, const QByteArray&)));
+    connect(d->dateListJob, SIGNAL(data(KIO::Job*,QByteArray)),
+            this, SLOT(slotDatesJobData(KIO::Job*,QByteArray)));
 }
 
 AlbumList AlbumManager::allPAlbums() const
@@ -3401,7 +3414,7 @@ void AlbumManager::slotDirWatchDirty(const QString& path)
 
     DatabaseParameters params = DatabaseAccess::parameters();
 
-    if (params.isSQLite())
+    if (params.isImgSQLite())
     {
         QFileInfo info(path);
         QDir dir;
@@ -3415,7 +3428,7 @@ void AlbumManager::slotDirWatchDirty(const QString& path)
             dir = info.dir();
         }
 
-        QFileInfo dbFile(params.SQLiteDatabaseFile());
+        QFileInfo dbFile(params.imgSQLiteDatabaseFile());
 
         // Workaround for broken KDirWatch in KDE 4.2.4
         if (path.startsWith(dbFile.filePath()))
