@@ -63,6 +63,7 @@ void ImageDelegate::ImageDelegatePrivate::clearRects()
     modDateRect          = QRect(0, 0, 0, 0);
     pixmapRect           = QRect(0, 0, 0, 0);
     nameRect             = QRect(0, 0, 0, 0);
+    titleRect            = QRect(0, 0, 0, 0);
     commentsRect         = QRect(0, 0, 0, 0);
     resolutionRect       = QRect(0, 0, 0, 0);
     sizeRect             = QRect(0, 0, 0, 0);
@@ -139,13 +140,13 @@ void ImageDelegate::setModel(QAbstractItemModel* model)
         connect(d->currentModel, SIGNAL(modelAboutToBeReset()),
                 this, SLOT(modelContentsChanged()));
 
-        connect(d->currentModel, SIGNAL(rowsAboutToBeInserted(const QModelIndex&, int, int)),
+        connect(d->currentModel, SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)),
                 this, SLOT(modelContentsChanged()));
 
-        connect(d->currentModel, SIGNAL(rowsAboutToBeRemoved(const QModelIndex&, int, int)),
+        connect(d->currentModel, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
                 this, SLOT(modelContentsChanged()));
 
-        connect(d->currentModel, SIGNAL(dataChanged(const QModelIndex&, const QModelIndex&)),
+        connect(d->currentModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
                 this, SLOT(modelContentsChanged()));
     }
 }
@@ -283,6 +284,11 @@ void ImageDelegate::paint(QPainter* p, const QStyleOptionViewItem& option, const
         drawName(p, d->nameRect, info.name());
     }
 
+    if (!d->titleRect.isNull())
+    {
+        drawTitle(p, d->titleRect, info.title());
+    }
+
     if (!d->commentsRect.isNull())
     {
         drawComments(p, d->commentsRect, info.comment());
