@@ -106,6 +106,7 @@ public:
         tooltipShowAlbumCategory(false),
         tooltipShowAlbumCaption(false),
         previewLoadFullImageSize(false),
+        previewShowIcons(true),
         showThumbbar(false),
         showFolderTreeViewItemsCount(false),
         treeThumbnailSize(0),
@@ -146,6 +147,7 @@ public:
     static const QString                configIconShowSizeEntry;
     static const QString                configIconShowDateEntry;
     static const QString                configIconShowModificationDateEntry;
+    static const QString                configIconShowTitleEntry;
     static const QString                configIconShowCommentsEntry;
     static const QString                configIconShowTagsEntry;
     static const QString                configIconShowOverlaysEntry;
@@ -177,6 +179,7 @@ public:
     static const QString                configToolTipsShowAlbumCategoryEntry;
     static const QString                configToolTipsShowAlbumCaptionEntry;
     static const QString                configPreviewLoadFullImageSizeEntry;
+    static const QString                configPreviewShowIconsEntry;
     static const QString                configShowThumbbarEntry;
     static const QString                configShowFolderTreeViewItemsCountEntry;
     static const QString                configEXIFRotateEntry;
@@ -216,6 +219,7 @@ public:
     bool                                iconShowSize;
     bool                                iconShowDate;
     bool                                iconShowModDate;
+    bool                                iconShowTitle;
     bool                                iconShowComments;
     bool                                iconShowResolution;
     bool                                iconShowTags;
@@ -256,6 +260,7 @@ public:
 
     // preview settings
     bool                                previewLoadFullImageSize;
+    bool                                previewShowIcons;
     bool                                showThumbbar;
 
     bool                                showFolderTreeViewItemsCount;
@@ -334,6 +339,7 @@ const QString AlbumSettings::AlbumSettingsPrivate::configIconShowResolutionEntry
 const QString AlbumSettings::AlbumSettingsPrivate::configIconShowSizeEntry("Icon Show Size");
 const QString AlbumSettings::AlbumSettingsPrivate::configIconShowDateEntry("Icon Show Date");
 const QString AlbumSettings::AlbumSettingsPrivate::configIconShowModificationDateEntry("Icon Show Modification Date");
+const QString AlbumSettings::AlbumSettingsPrivate::configIconShowTitleEntry("Icon Show Title");
 const QString AlbumSettings::AlbumSettingsPrivate::configIconShowCommentsEntry("Icon Show Comments");
 const QString AlbumSettings::AlbumSettingsPrivate::configIconShowTagsEntry("Icon Show Tags");
 const QString AlbumSettings::AlbumSettingsPrivate::configIconShowRatingEntry("Icon Show Rating");
@@ -365,6 +371,7 @@ const QString AlbumSettings::AlbumSettingsPrivate::configToolTipsShowAlbumCollec
 const QString AlbumSettings::AlbumSettingsPrivate::configToolTipsShowAlbumCategoryEntry("ToolTips Show Album Category");
 const QString AlbumSettings::AlbumSettingsPrivate::configToolTipsShowAlbumCaptionEntry("ToolTips Show Album Caption");
 const QString AlbumSettings::AlbumSettingsPrivate::configPreviewLoadFullImageSizeEntry("Preview Load Full Image Size");
+const QString AlbumSettings::AlbumSettingsPrivate::configPreviewShowIconsEntry("Preview Show Icons");
 const QString AlbumSettings::AlbumSettingsPrivate::configShowThumbbarEntry("Show Thumbbar");
 const QString AlbumSettings::AlbumSettingsPrivate::configShowFolderTreeViewItemsCountEntry("Show Folder Tree View Items Count");
 const QString AlbumSettings::AlbumSettingsPrivate::configEXIFRotateEntry("EXIF Rotate");
@@ -455,6 +462,7 @@ void AlbumSettings::init()
     d->iconShowSize                 = false;
     d->iconShowDate                 = true;
     d->iconShowModDate              = true;
+    d->iconShowTitle                = true;
     d->iconShowComments             = true;
     d->iconShowResolution           = false;
     d->iconShowTags                 = true;
@@ -490,6 +498,7 @@ void AlbumSettings::init()
     d->tooltipShowAlbumCaption      = true;
 
     d->previewLoadFullImageSize     = false;
+    d->previewShowIcons             = true;
     d->showThumbbar                 = true;
 
     d->recursiveAlbums              = false;
@@ -555,6 +564,7 @@ void AlbumSettings::readSettings()
     d->iconShowSize                 = group.readEntry(d->configIconShowSizeEntry,                 false);
     d->iconShowDate                 = group.readEntry(d->configIconShowDateEntry,                 true);
     d->iconShowModDate              = group.readEntry(d->configIconShowModificationDateEntry,     true);
+    d->iconShowTitle                = group.readEntry(d->configIconShowTitleEntry,                true);
     d->iconShowComments             = group.readEntry(d->configIconShowCommentsEntry,             true);
     d->iconShowTags                 = group.readEntry(d->configIconShowTagsEntry,                 true);
     d->iconShowOverlays             = group.readEntry(d->configIconShowOverlaysEntry,             true);
@@ -589,6 +599,7 @@ void AlbumSettings::readSettings()
     d->tooltipShowAlbumCaption      = group.readEntry(d->configToolTipsShowAlbumCaptionEntry,     true);
 
     d->previewLoadFullImageSize     = group.readEntry(d->configPreviewLoadFullImageSizeEntry,     false);
+    d->previewShowIcons             = group.readEntry(d->configPreviewShowIconsEntry,             true);
     d->showThumbbar                 = group.readEntry(d->configShowThumbbarEntry,                 true);
 
     d->showFolderTreeViewItemsCount = group.readEntry(d->configShowFolderTreeViewItemsCountEntry, false);
@@ -664,6 +675,7 @@ void AlbumSettings::saveSettings()
     group.writeEntry(d->configIconShowSizeEntry,                 d->iconShowSize);
     group.writeEntry(d->configIconShowDateEntry,                 d->iconShowDate);
     group.writeEntry(d->configIconShowModificationDateEntry,     d->iconShowModDate);
+    group.writeEntry(d->configIconShowTitleEntry,                d->iconShowTitle);
     group.writeEntry(d->configIconShowCommentsEntry,             d->iconShowComments);
     group.writeEntry(d->configIconShowTagsEntry,                 d->iconShowTags);
     group.writeEntry(d->configIconShowOverlaysEntry,             d->iconShowOverlays);
@@ -698,6 +710,7 @@ void AlbumSettings::saveSettings()
     group.writeEntry(d->configToolTipsShowAlbumCaptionEntry,     d->tooltipShowAlbumCaption);
 
     group.writeEntry(d->configPreviewLoadFullImageSizeEntry,     d->previewLoadFullImageSize);
+    group.writeEntry(d->configPreviewShowIconsEntry,             d->previewShowIcons);
     group.writeEntry(d->configShowThumbbarEntry,                 d->showThumbbar);
 
     group.writeEntry(d->configShowFolderTreeViewItemsCountEntry, d->showFolderTreeViewItemsCount);
@@ -747,15 +760,26 @@ void AlbumSettings::emitSetupChanged()
     emit setupChanged();
 }
 
-QString AlbumSettings::getDatabaseFilePath() const
+QString AlbumSettings::getImgDatabaseFilePath() const
 {
-    return d->databaseParams.getDatabaseNameOrDir();
+    return d->databaseParams.getImgDatabaseNameOrDir();
 }
 
-void AlbumSettings::setDatabaseFilePath(const QString& path)
+QString AlbumSettings::getTmbDatabaseFilePath() const
 {
-    d->databaseParams.setDatabasePath(path);
-    d->databaseParams.setThumbsDatabasePath(path);
+    return d->databaseParams.getImgDatabaseNameOrDir();
+}
+
+void AlbumSettings::setImgDatabaseFilePath(const QString& path)
+{
+    d->databaseParams.setImgDatabasePath(path);
+    d->databaseParams.setTmbDatabasePath(path);
+}
+
+void AlbumSettings::setTmbDatabaseFilePath(const QString& path)
+{
+    d->databaseParams.setImgDatabasePath(path);
+    d->databaseParams.setTmbDatabasePath(path);
 }
 
 void AlbumSettings::setShowSplashScreen(bool val)
@@ -1013,6 +1037,16 @@ bool AlbumSettings::getIconShowSize() const
     return d->iconShowSize;
 }
 
+void AlbumSettings::setIconShowTitle(bool val)
+{
+    d->iconShowTitle = val;
+}
+
+bool AlbumSettings::getIconShowTitle() const
+{
+    return d->iconShowTitle;
+}
+
 void AlbumSettings::setIconShowComments(bool val)
 {
     d->iconShowComments = val;
@@ -1450,6 +1484,16 @@ bool AlbumSettings::getPreviewLoadFullImageSize() const
     return d->previewLoadFullImageSize;
 }
 
+void AlbumSettings::setPreviewShowIcons(bool val)
+{
+    d->previewShowIcons = val;
+}
+
+bool AlbumSettings::getPreviewShowIcons() const
+{
+    return d->previewShowIcons;
+}
+
 void AlbumSettings::setRecurseAlbums(bool val)
 {
     d->recursiveAlbums = val;
@@ -1524,49 +1568,144 @@ void AlbumSettings::setDatabaseParameters(const DatabaseParameters& params)
     d->databaseParams = params;
 }
 
-QString AlbumSettings::getDatabaseType() const
+QString AlbumSettings::getImgDatabaseType() const
 {
-    return d->databaseParams.databaseType;
+    return d->databaseParams.imgDatabaseType;
 }
 
-void AlbumSettings::setDatabaseType(const QString& databaseType)
+void AlbumSettings::setImgDatabaseType(const QString& databaseType)
 {
-    d->databaseParams.databaseType = databaseType;
+    d->databaseParams.imgDatabaseType = databaseType;
 }
 
-QString AlbumSettings::getDatabaseConnectoptions() const
+QString AlbumSettings::getImgDatabaseConnectoptions() const
 {
-    return d->databaseParams.connectOptions;
+    return d->databaseParams.imgConnectOptions;
 }
 
-QString AlbumSettings::getDatabaseName() const
+QString AlbumSettings::getImgDatabaseName() const
 {
-    return d->databaseParams.databaseName;
+    return d->databaseParams.imgDatabaseName;
 }
 
-QString AlbumSettings::getDatabaseNameThumbnails() const
+QString AlbumSettings::getImgDatabaseHostName() const
 {
-    return d->databaseParams.databaseNameThumbnails;
+    return d->databaseParams.imgHostName;
 }
 
-QString AlbumSettings::getDatabaseHostName() const
+QString AlbumSettings::getImgDatabasePassword() const
 {
-    return d->databaseParams.hostName;
+    return d->databaseParams.imgPassword;
 }
 
-QString AlbumSettings::getDatabasePassword() const
+int AlbumSettings::getImgDatabasePort() const
 {
-    return d->databaseParams.password;
+    return d->databaseParams.imgPort;
 }
 
-int AlbumSettings::getDatabasePort() const
+QString AlbumSettings::getImgDatabaseUserName() const
 {
-    return d->databaseParams.port;
+    return d->databaseParams.imgUserName;
 }
 
-QString AlbumSettings::getDatabaseUserName() const
+void AlbumSettings::setImgDatabaseConnectoptions(const QString& connectoptions)
 {
-    return d->databaseParams.userName;
+    d->databaseParams.imgConnectOptions = connectoptions;
+}
+
+void AlbumSettings::setImgDatabaseName(const QString& databaseName)
+{
+    d->databaseParams.imgDatabaseName = databaseName;
+}
+
+void AlbumSettings::setImgDatabaseHostName(const QString& hostName)
+{
+    d->databaseParams.imgHostName = hostName;
+}
+
+void AlbumSettings::setImgDatabasePassword(const QString& password)
+{
+    d->databaseParams.imgPassword = password;
+}
+
+void AlbumSettings::setImgDatabasePort(int port)
+{
+    d->databaseParams.imgPort = port;
+}
+
+void AlbumSettings::setImgDatabaseUserName(const QString& userName)
+{
+    d->databaseParams.imgUserName = userName;
+}
+
+QString AlbumSettings::getTmbDatabaseType() const
+{
+    return d->databaseParams.tmbDatabaseType;
+}
+
+void AlbumSettings::setTmbDatabaseType(const QString& databaseType)
+{
+    d->databaseParams.tmbDatabaseType = databaseType;
+}
+
+QString AlbumSettings::getTmbDatabaseConnectoptions() const
+{
+    return d->databaseParams.tmbConnectOptions;
+}
+
+QString AlbumSettings::getTmbDatabaseName() const
+{
+    return d->databaseParams.tmbDatabaseName;
+}
+
+QString AlbumSettings::getTmbDatabaseHostName() const
+{
+    return d->databaseParams.tmbHostName;
+}
+
+QString AlbumSettings::getTmbDatabasePassword() const
+{
+    return d->databaseParams.tmbPassword;
+}
+
+int AlbumSettings::getTmbDatabasePort() const
+{
+    return d->databaseParams.tmbPort;
+}
+
+QString AlbumSettings::getTmbDatabaseUserName() const
+{
+    return d->databaseParams.tmbUserName;
+}
+
+void AlbumSettings::setTmbDatabaseConnectoptions(const QString& connectoptions)
+{
+    d->databaseParams.tmbConnectOptions = connectoptions;
+}
+
+void AlbumSettings::setTmbDatabaseName(const QString& databaseName)
+{
+    d->databaseParams.tmbDatabaseName = databaseName;
+}
+
+void AlbumSettings::setTmbDatabaseHostName(const QString& hostName)
+{
+    d->databaseParams.tmbHostName = hostName;
+}
+
+void AlbumSettings::setTmbDatabasePassword(const QString& password)
+{
+    d->databaseParams.tmbPassword = password;
+}
+
+void AlbumSettings::setTmbDatabasePort(int port)
+{
+    d->databaseParams.tmbPort = port;
+}
+
+void AlbumSettings::setTmbDatabaseUserName(const QString& userName)
+{
+    d->databaseParams.tmbUserName = userName;
 }
 
 bool AlbumSettings::getInternalDatabaseServer() const
@@ -1574,41 +1713,6 @@ bool AlbumSettings::getInternalDatabaseServer() const
     return d->databaseParams.internalServer;
 }
 
-void AlbumSettings::setDatabaseConnectoptions(const QString& connectoptions)
-{
-    d->databaseParams.connectOptions = connectoptions;
-}
-
-void AlbumSettings::setDatabaseName(const QString& databaseName)
-{
-    d->databaseParams.databaseName = databaseName;
-}
-
-void AlbumSettings::setDatabaseNameThumbnails(const QString& databaseNameThumbnails)
-{
-    d->databaseParams.databaseNameThumbnails = databaseNameThumbnails;
-}
-
-void AlbumSettings::setDatabaseHostName(const QString& hostName)
-{
-    d->databaseParams.hostName = hostName;
-}
-
-void AlbumSettings::setDatabasePassword(const QString& password)
-{
-    d->databaseParams.password = password;
-}
-
-void AlbumSettings::setDatabasePort(int port)
-{
-    d->databaseParams.port = port;
-}
-
-void AlbumSettings::setDatabaseUserName(const QString& userName)
-{
-    d->databaseParams.userName = userName;
-}
-
 void AlbumSettings::setInternalDatabaseServer(const bool useInternalDBServer)
 {
     d->databaseParams.internalServer = useInternalDBServer;
