@@ -76,8 +76,8 @@ WelcomePageView::WelcomePageView(QWidget* parent)
 
     // ------------------------------------------------------------
 
-    connect(browserExtension(), SIGNAL(openUrlRequest(const KUrl&, const KParts::OpenUrlArguments&, const KParts::BrowserArguments&)),
-            this, SLOT(slotUrlOpen(const KUrl&)));
+    connect(browserExtension(), SIGNAL(openUrlRequest(KUrl,KParts::OpenUrlArguments,KParts::BrowserArguments)),
+            this, SLOT(slotUrlOpen(KUrl)));
 
     connect(ThemeManager::instance(), SIGNAL(signalThemeChanged()),
             this, SLOT(slotThemeChanged()));
@@ -100,15 +100,20 @@ QString WelcomePageView::infoPage() const
     newFeatures << i18n("XMP metadata sidecar support;");
     newFeatures << i18n("Reverse geo-coding support;");
     newFeatures << i18n("Image versioning support;");
-    newFeatures << i18n("Face detection and recognition support;");
+    newFeatures << i18n("Face detection support;");
     newFeatures << i18n("Tag keyboard shortcuts support;");
     newFeatures << i18n("Pick Labels support to improve photograph selection;");
     newFeatures << i18n("Color Labels support to improve photograph workflow;");
+    newFeatures << i18n("Image title metadata support;");
     newFeatures << i18n("Re-designed Filters view on right sidebar to perform icon-view items filtering;");
     newFeatures << i18n("New options to group/ungroup items from icon-view;");
     newFeatures << i18n("New option to show file format over icon-view items;");
+    newFeatures << i18n("New option to setup a collection as default download place with camera device;");
+    newFeatures << i18n("New option to filter camera icon-view;");
+    newFeatures << i18n("New option to download items from camera in just one-click;");
+    newFeatures << i18n("Speed-up improvements to be connected to camera device;");
     newFeatures << i18n("Support for the latest camera RAW files using <a href=\"http://www.libraw.org\">LibRaw</a>, "
-                        "including Foveon-sensor-based cameras, Nikon D7000, Canon 60D, Pentax K5, Olympus E5 and Sony A450 "
+                        "including Foveon-sensor-based cameras, Nikon D7000 and D5100, Canon 600D and 1100D, Pentax K5, Olympus E5 and Sony Alpha/Nex "
                         "(see the Help menu for the full list of RAW cameras supported);");
     newFeatures << i18n("New advanced RAW decoding settings backported from RawTherapee project;");
     newFeatures << i18n("...and much more.");
@@ -117,7 +122,7 @@ QString WelcomePageView::infoPage() const
 
     for (int i = 0 ; i < newFeatures.count() ; ++i)
     {
-        featureItems += i18n("<li>%1</li>\n", newFeatures[i] );
+        featureItems += i18n("<li>%1</li>\n", newFeatures.at(i) );
     }
 
     QString info =
