@@ -188,11 +188,11 @@ bool DatabaseCoreBackendPrivate::open(QSqlDatabase& db)
 
     QThread* thread = QThread::currentThread();
 
-    db = QSqlDatabase::addDatabase(parameters.databaseType, connectionName(thread));
+    db = QSqlDatabase::addDatabase(parameters.imgDatabaseType, connectionName(thread));
 
-    QString connectOptions = parameters.connectOptions;
+    QString connectOptions = parameters.imgConnectOptions;
 
-    if (parameters.isSQLite())
+    if (parameters.isImgSQLite())
     {
         QStringList toAdd;
         // enable shared cache, especially useful with SQLite >= 3.5.0
@@ -208,18 +208,25 @@ bool DatabaseCoreBackendPrivate::open(QSqlDatabase& db)
         connectOptions += toAdd.join(";");
     }
 
-    db.setDatabaseName(parameters.databaseName);
+    db.setDatabaseName(parameters.imgDatabaseName);
     db.setConnectOptions(connectOptions);
-    db.setHostName(parameters.hostName);
-    db.setPort(parameters.port);
-    db.setUserName(parameters.userName);
-    db.setPassword(parameters.password);
+    db.setHostName(parameters.imgHostName);
+    db.setPort(parameters.imgPort);
+    db.setUserName(parameters.imgUserName);
+    db.setPassword(parameters.imgPassword);
 
     bool success = db.open();
 
     if (success==false)
     {
         kDebug() << "Error while opening the database. Error was <" << db.lastError() << ">";
+        kDebug() << "parameters.imgDatabaseType <" << parameters.imgDatabaseType << ">";
+        kDebug() << "parameters.imgDatabaseName <" << parameters.imgDatabaseName << ">";
+        kDebug() << "connectOptions             <" << connectOptions << ">";
+        kDebug() << "parameters.imgHostName     <" << parameters.imgHostName << ">";
+        kDebug() << "parameters.imgPort         <" << parameters.imgPort << ">";
+        kDebug() << "parameters.imgUserName     <" << parameters.imgUserName << ">";
+        kDebug() << "parameters.imgPassword     <" << parameters.imgPassword << ">";
     }
 
     threadDatabases[thread]  = db;
@@ -274,18 +281,18 @@ bool DatabaseCoreBackendPrivate::isInUIThread() const
 
 bool DatabaseCoreBackendPrivate::reconnectOnError() const
 {
-    return parameters.isMySQL();
+    return parameters.isImgMySQL();
 }
 
 bool DatabaseCoreBackendPrivate::isSQLiteLockError(const SqlQuery& query) const
 {
-    return parameters.isSQLite()
+    return parameters.isImgSQLite()
            && (query.lastError().number() == 5 /*SQLITE_BUSY*/ || query.lastError().number() == 6/*SQLITE_LOCKED*/);
 }
 
 bool DatabaseCoreBackendPrivate::isSQLiteLockTransactionError(const QSqlError& lastError) const
 {
-    return parameters.isSQLite()
+    return parameters.isImgSQLite()
            && lastError.type() == QSqlError::TransactionError
            && lastError.databaseText() == QLatin1String("database is locked");
     // wouldnt it be great if they gave us the database error number...
@@ -294,7 +301,7 @@ bool DatabaseCoreBackendPrivate::isSQLiteLockTransactionError(const QSqlError& l
 bool DatabaseCoreBackendPrivate::isConnectionError(const SqlQuery& query) const
 {
     // the backend returns connection error e.g. for Constraint Failed errors.
-    if (parameters.isSQLite())
+    if (parameters.isImgSQLite())
     {
         return false;
     }
@@ -583,7 +590,7 @@ DatabaseCoreBackend::~DatabaseCoreBackend()
 DatabaseConfigElement DatabaseCoreBackend::configElement() const
 {
     Q_D(const DatabaseCoreBackend);
-    return DatabaseConfigElement::element(d->parameters.databaseType);
+    return DatabaseConfigElement::element(d->parameters.imgDatabaseType);
 }
 
 DatabaseAction DatabaseCoreBackend::getDBAction(const QString& actionName) const
@@ -745,7 +752,7 @@ void DatabaseCoreBackend::slotMainThreadFinished()
 
 bool DatabaseCoreBackend::isCompatible(const DatabaseParameters& parameters)
 {
-    return QSqlDatabase::drivers().contains(parameters.databaseType);
+    return QSqlDatabase::drivers().contains(parameters.imgDatabaseType);
 }
 
 bool DatabaseCoreBackend::open(const DatabaseParameters& parameters)
@@ -1081,7 +1088,7 @@ void DatabaseCoreBackend::execQuery(SqlQuery& query, const QList<QVariant>& boun
 {
     for (int i=0; i<boundValues.size(); ++i)
     {
-        query.bindValue(i, boundValues[i]);
+        query.bindValue(i, boundValues.at(i));
     }
 
     exec(query);
@@ -1230,9 +1237,9 @@ SqlQuery DatabaseCoreBackend::execQuery(const QString& sql, const QMap<QString,
 
     SqlQuery query = prepareQuery(preparedString);
 
-    for (int i=0; i<valuesToBind.size(); i++)
+    for (int i=0; i<valuesToBind.size(); ++i)
     {
-        query.bindValue(i, valuesToBind[i]);
+        query.bindValue(i, valuesToBind.at(i));
     }
 
     exec(query);
@@ -1246,9 +1253,9 @@ DatabaseCoreBackend::QueryState DatabaseCoreBackend::execUpsertDBAction(const Da
 
     QMap<QString, QVariant> fieldValueMap;
 
-    for (int i=0; i<fieldNames.size(); i++)
+    for (int i=0; i<fieldNames.size(); ++i)
     {
-        fieldValueMap.insert(fieldNames[i], values[i]);
+        fieldValueMap.insert(fieldNames.at(i), values.at(i));
     }
 
     DBActionType fieldValueList = DBActionType::value(fieldValueMap);
