@@ -617,8 +617,8 @@ public:
                 return;
             }
 
-            double lon = list[0];
-            double lat = list[1];
+            double lon = list.at(0);
+            double lat = list.at(1);
 
             sql += " ( ";
 
@@ -734,10 +734,10 @@ public:
             // where the searched region contains any lon,lat
             //  where lon1 < lon < lon2 and lat1 < lat < lat2.
             double lon1,lat1,lon2,lat2;
-            lon1 = list[0];
-            lat1 = list[1];
-            lon2 = list[2];
-            lat2 = list[3];
+            lon1 = list.at(0);
+            lat1 = list.at(1);
+            lon2 = list.at(2);
+            lat2 = list.at(3);
 
             sql += " ( ";
             addRectanglePositionSearch(lon1, lat1, lon2, lat2);
@@ -1155,7 +1155,7 @@ bool ImageQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
                "  WHERE type=? AND comment ";
         ImageQueryBuilder::addSqlRelation(sql, relation);
         sql += " ?)) ";
-        *boundValues << DatabaseComment::Comment << fieldQuery.prepareForLike(reader.value());
+        *boundValues << DatabaseComment::Title << fieldQuery.prepareForLike(reader.value());
     }
     else if (name == "imagetagproperty")
     {
@@ -1205,7 +1205,7 @@ bool ImageQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
                 selectQuery += "%1property=? AND %1value ";
                 ImageQueryBuilder::addSqlRelation(selectQuery, relation);
                 selectQuery += " ? ";
-                *boundValues << values[0] << fieldQuery.prepareForLike(values[1]);
+                *boundValues << values.at(0) << fieldQuery.prepareForLike(values.at(1));
             }
 
             // This indicates that the ImageTagProperties is joined in the SELECT query,
@@ -1249,6 +1249,9 @@ bool ImageQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
         addSqlOperator(sql, SearchXml::Or, false);
         buildField(sql, reader, "comment", boundValues, hooks);
 
+        addSqlOperator(sql, SearchXml::Or, false);
+        buildField(sql, reader, "title", boundValues, hooks);
+
         sql += " ) ";
     }
     else if (name == "similarity")
@@ -1463,7 +1466,7 @@ QString ImageQueryBuilder::convertFromUrlToXml(const KUrl& url) const
 
     QStringList strList = url.path().split(' ', QString::SkipEmptyParts);
 
-    for ( QStringList::Iterator it = strList.begin(); it != strList.end(); ++it )
+    for ( QStringList::const_iterator it = strList.constBegin(); it != strList.constEnd(); ++it )
     {
         bool ok;
         int  num = (*it).toInt(&ok);
@@ -1676,7 +1679,7 @@ QString ImageQueryBuilder::buildQueryFromUrl(const KUrl& url, QList<QVariant> *b
 
     QStringList strList = url.path().split(' ', QString::SkipEmptyParts);
 
-    for ( QStringList::Iterator it = strList.begin(); it != strList.end(); ++it )
+    for ( QStringList::const_iterator it = strList.constBegin(); it != strList.constEnd(); ++it )
     {
         bool ok;
         int  num = (*it).toInt(&ok);
