@@ -42,11 +42,13 @@
 #include "albumdb.h"
 #include "collectionlocation.h"
 #include "collectionmanager.h"
+#include "facetagseditor.h"
 #include "imagecomments.h"
 #include "imagecopyright.h"
 #include "imageextendedproperties.h"
 #include "imagehistorygraph.h"
 #include "metadatasettings.h"
+#include "tagregion.h"
 #include "tagscache.h"
 
 namespace Digikam
@@ -218,8 +220,7 @@ void ImageScanner::prepareImage()
 {
     m_scanInfo.itemName         = m_fileInfo.fileName();
     m_scanInfo.modificationDate = m_fileInfo.lastModified();
-    // there is a limit here for file size <2TB
-    m_scanInfo.fileSize         = (int)m_fileInfo.size();
+    m_scanInfo.fileSize         = m_fileInfo.size();
     // category is set by setCategory
 
     // the QByteArray is an ASCII hex string
@@ -257,6 +258,7 @@ void ImageScanner::scanFile(ScanMode mode)
         if (m_scanInfo.category == DatabaseItem::Image)
         {
             scanImageInformation();
+            scanFaces();
             scanImageHistoryIfModified();
         }
     }
@@ -274,6 +276,7 @@ void ImageScanner::scanFile(ScanMode mode)
                 scanImageCopyright();
                 scanIPTCCore();
                 scanTags();
+                scanFaces();
                 scanImageHistory();
             }
         }
@@ -307,7 +310,7 @@ void ImageScanner::scanImageInformation()
         QVariantList metadataInfos = m_metadata.getMetadataFields(fields);
 
         // creation date: fall back to file system property
-        if (metadataInfos[1].isNull() || !metadataInfos[1].toDateTime().isValid())
+        if (metadataInfos.at(1).isNull() || !metadataInfos.at(1).toDateTime().isValid())
         {
             metadataInfos[1] = creationDateFromFilesystem(m_fileInfo);
         }
@@ -315,7 +318,7 @@ void ImageScanner::scanImageInformation()
         // Some fields should only be overwritten if set in metadata
         if (m_scanMode == Rescan)
         {
-            if (metadataInfos[0].isNull() || metadataInfos[0].toInt() == -1)
+            if (metadataInfos.at(0).isNull() || metadataInfos.at(0).toInt() == -1)
             {
                 dbFields &= ~DatabaseFields::Rating;
                 metadataInfos.removeAt(0);
@@ -448,15 +451,15 @@ void ImageScanner::scanImageComments()
     }
 
     // Headline
-    if (!metadataInfos[0].isNull())
+    if (!metadataInfos.at(0).isNull())
     {
-        comments.addHeadline(metadataInfos[0].toString());
+        comments.addHeadline(metadataInfos.at(0).toString());
     }
 
     // Title
-    if (!metadataInfos[1].isNull())
+    if (!metadataInfos.at(1).isNull())
     {
-        comments.addTitle(metadataInfos[1].toString());
+        comments.addTitle(metadataInfos.at(1).toMap()["x-default"].toString());
     }
 }
 
@@ -493,9 +496,9 @@ void ImageScanner::scanIPTCCore()
 
     ImageExtendedProperties props(m_scanInfo.id);
 
-    if (!metadataInfos[0].isNull())
+    if (!metadataInfos.at(0).isNull())
     {
-        IptcCoreLocationInfo loc = metadataInfos[0].value<IptcCoreLocationInfo>();
+        IptcCoreLocationInfo loc = metadataInfos.at(0).value<IptcCoreLocationInfo>();
 
         if (!loc.isNull())
         {
@@ -503,24 +506,24 @@ void ImageScanner::scanIPTCCore()
         }
     }
 
-    if (!metadataInfos[1].isNull())
+    if (!metadataInfos.at(1).isNull())
     {
-        props.setIntellectualGenre(metadataInfos[1].toString());
+        props.setIntellectualGenre(metadataInfos.at(1).toString());
     }
 
-    if (!metadataInfos[2].isNull())
+    if (!metadataInfos.at(2).isNull())
     {
-        props.setJobId(metadataInfos[2].toString());
+        props.setJobId(metadataInfos.at(2).toString());
     }
 
-    if (!metadataInfos[3].isNull())
+    if (!metadataInfos.at(3).isNull())
     {
-        props.setScene(metadataInfos[3].toStringList());
+        props.setScene(metadataInfos.at(3).toStringList());
     }
 
-    if (!metadataInfos[4].isNull())
+    if (!metadataInfos.at(4).isNull())
     {
-        props.setSubjectCode(metadataInfos[4].toStringList());
+        props.setSubjectCode(metadataInfos.at(4).toStringList());
     }
 }
 
@@ -577,6 +580,44 @@ void ImageScanner::scanTags()
     }
 }
 
+void ImageScanner::scanFaces()
+{
+    QSize size = m_img.size();
+    if (!size.isValid())
+    {
+        return;
+    }
+
+    QMap<QString,QVariant> metadataFacesMap;
+    if (!m_metadata.getImageFacesMap(metadataFacesMap))
+    {
+        return;
+    }
+
+    QMap<QString,QVariant>::const_iterator it;
+    for (it = metadataFacesMap.constBegin(); it != metadataFacesMap.constEnd(); ++it)
+    {
+        QString name = it.key();
+        QRectF rect  = it.value().toRectF();
+
+        if (name.isEmpty() || !rect.isValid())
+        {
+            continue;
+        }
+
+        int tagId = FaceTags::getOrCreateTagForPerson(name);
+        if (!tagId)
+        {
+            kDebug() << "Failed to create a person tag for name" << name;
+        }
+
+        TagRegion region(TagRegion::relativeToAbsolute(rect, size));
+
+        FaceTagsEditor editor;
+        editor.add(m_scanInfo.id, tagId, region, false);
+    }
+}
+
 void ImageScanner::scanImageHistory()
 {
     /** Stage 1 of history scanning */
@@ -703,9 +744,9 @@ void ImageScanner::tagImageHistoryGraph(qlonglong id)
     // get category info
     QList<qlonglong> originals, intermediates, currents;
     QHash<ImageInfo, HistoryImageId::Types> types = graph.categorize();
-    QHash<ImageInfo, HistoryImageId::Types>::iterator it;
+    QHash<ImageInfo, HistoryImageId::Types>::const_iterator it;
 
-    for (it = types.begin(); it != types.end(); ++it)
+    for (it = types.constBegin(); it != types.constEnd(); ++it)
     {
         kDebug() << "Image" << it.key().id() << "type" << it.value();
         HistoryImageId::Types types = it.value();
@@ -1000,13 +1041,13 @@ void ImageScanner::scanVideoFile()
         metadataInfos = m_metadata.getMetadataFields(fields);
 
         // if invalid, start with -1 rating
-        if (metadataInfos[0].isNull())
+        if (metadataInfos.at(0).isNull())
         {
             metadataInfos[0] = -1;
         }
 
         // creation date: fall back to file system property
-        if (metadataInfos[1].isNull() || !metadataInfos[1].toDateTime().isValid())
+        if (metadataInfos.at(1).isNull() || !metadataInfos.at(1).toDateTime().isValid())
         {
             metadataInfos[1] = creationDateFromFilesystem(m_fileInfo);
         }
@@ -1413,22 +1454,22 @@ void ImageScanner::fillCommonContainer(qlonglong imageid, ImageCommonContainer*
 
     if (!imagesFields.isEmpty())
     {
-        container->fileName             = imagesFields[0].toString();
-        container->fileModificationDate = imagesFields[1].toDateTime();
-        container->fileSize             = imagesFields[2].toInt();
+        container->fileName             = imagesFields.at(0).toString();
+        container->fileModificationDate = imagesFields.at(1).toDateTime();
+        container->fileSize             = imagesFields.at(2).toLongLong();
     }
 
     if (!imageInformationFields.isEmpty())
     {
-        container->rating           = imageInformationFields[0].toInt();
-        container->creationDate     = imageInformationFields[1].toDateTime();
-        container->digitizationDate = imageInformationFields[2].toDateTime();
-        container->orientation      = DMetadata::valueToString(imageInformationFields[3], MetadataInfo::Orientation);
-        container->width            = imageInformationFields[4].toInt();
-        container->height           = imageInformationFields[5].toInt();
-        container->format           = formatToString(imageInformationFields[6].toString());
-        container->colorDepth       = imageInformationFields[7].toInt();
-        container->colorModel       = DImg::colorModelToString((DImg::COLORMODEL)imageInformationFields[8].toInt());
+        container->rating           = imageInformationFields.at(0).toInt();
+        container->creationDate     = imageInformationFields.at(1).toDateTime();
+        container->digitizationDate = imageInformationFields.at(2).toDateTime();
+        container->orientation      = DMetadata::valueToString(imageInformationFields.at(3), MetadataInfo::Orientation);
+        container->width            = imageInformationFields.at(4).toInt();
+        container->height           = imageInformationFields.at(5).toInt();
+        container->format           = formatToString(imageInformationFields.at(6).toString());
+        container->colorDepth       = imageInformationFields.at(7).toInt();
+        container->colorModel       = DImg::colorModelToString((DImg::COLORMODEL)imageInformationFields.at(8).toInt());
     }
 }
 
@@ -1449,22 +1490,22 @@ void ImageScanner::fillMetadataContainer(qlonglong imageid, ImageMetadataContain
     QStringList strings = DMetadata::valuesToString(fields, allImageMetadataFields());
 
     // associate with hard-coded variables
-    container->make                         = strings[0];
-    container->model                        = strings[1];
-    container->lens                         = strings[2];
-    container->aperture                     = strings[3];
-    container->focalLength                  = strings[4];
-    container->focalLength35                = strings[5];
-    container->exposureTime                 = strings[6];
-    container->exposureProgram              = strings[7];
-    container->exposureMode                 = strings[8];
-    container->sensitivity                  = strings[9];
-    container->flashMode                    = strings[10];
-    container->whiteBalance                 = strings[11];
-    container->whiteBalanceColorTemperature = strings[12];
-    container->meteringMode                 = strings[13];
-    container->subjectDistance              = strings[14];
-    container->subjectDistanceCategory      = strings[15];
+    container->make                         = strings.at(0);
+    container->model                        = strings.at(1);
+    container->lens                         = strings.at(2);
+    container->aperture                     = strings.at(3);
+    container->focalLength                  = strings.at(4);
+    container->focalLength35                = strings.at(5);
+    container->exposureTime                 = strings.at(6);
+    container->exposureProgram              = strings.at(7);
+    container->exposureMode                 = strings.at(8);
+    container->sensitivity                  = strings.at(9);
+    container->flashMode                    = strings.at(10);
+    container->whiteBalance                 = strings.at(11);
+    container->whiteBalanceColorTemperature = strings.at(12);
+    container->meteringMode                 = strings.at(13);
+    container->subjectDistance              = strings.at(14);
+    container->subjectDistanceCategory      = strings.at(15);
 }
 
 } // namespace Digikam
