@@ -281,8 +281,8 @@ void TagsCache::initialize()
         return;
     }
 
-    connect(DatabaseAccess::databaseWatch(), SIGNAL(tagChange(const TagChangeset&)),
-            this, SLOT(slotTagChanged(const TagChangeset&)),
+    connect(DatabaseAccess::databaseWatch(), SIGNAL(tagChange(TagChangeset)),
+            this, SLOT(slotTagChanged(TagChangeset)),
             Qt::DirectConnection);
 
     d->initialized = true;
@@ -522,9 +522,9 @@ int TagsCache::tagForPath(const QString& tagPath) const
 
         // Check hierarchy, from bottom to top
         bool foundParentTag                 = true;
-        QStringList::iterator parentTagName = tagHierarchy.end();
+        QStringList::const_iterator parentTagName = tagHierarchy.constEnd();
 
-        while (foundParentTag && parentTagName != tagHierarchy.begin())
+        while (foundParentTag && parentTagName != tagHierarchy.constBegin())
         {
             --parentTagName;
 
@@ -701,6 +701,14 @@ int TagsCache::getOrCreateTag(const QString& tagPath)
     if (!id)
     {
         id = createTag(tagPath);
+
+        // There is a weakness when createTag is called concurrently.
+        // The attempt coming second to DatabaseAccess will fail, but the tag was created
+        // So at least try again finding the tag read-only.
+        if (id == -1)
+        {
+            id = tagForPath(tagPath);
+        }
     }
 
     return id;
@@ -816,10 +824,10 @@ QList<int> TagsCache::tagsWithPropertyCached(const QString& property) const
     d->checkProperties();
     {
         QReadLocker locker(&d->lock);
-        QHash<QString, QList<int> >::iterator it;
-        it = d->tagsWithProperty.find(property);
+        QHash<QString, QList<int> >::const_iterator it;
+        it = d->tagsWithProperty.constFind(property);
 
-        if (it != d->tagsWithProperty.end())
+        if (it != d->tagsWithProperty.constEnd())
         {
             return it.value();
         }
