@@ -47,142 +47,17 @@
 
 // Local includes
 
+#include "curvescontainer.h"
 #include "filteraction.h"
 #include "globals.h"
 
 namespace Digikam
 {
 
-const int ImageCurves::NUM_POINTS = 17;
-const int ImageCurves::NUM_CHANNELS = 5;
+const int ImageCurves::NUM_POINTS       = 17;
+const int ImageCurves::NUM_CHANNELS     = 5;
 const int ImageCurves::MULTIPLIER_16BIT = 255;
 
-CurvesContainer::CurvesContainer()
-    : curvesType(ImageCurves::CURVE_SMOOTH), sixteenBit(false)
-{
-}
-
-CurvesContainer::CurvesContainer(int type, bool sixteenBit)
-    : curvesType((ImageCurves::CurveType)type), sixteenBit(sixteenBit)
-{
-}
-
-bool CurvesContainer::isEmpty() const
-{
-    for (int i=0; i<ColorChannels; i++)
-    {
-        if (!values[i].isEmpty())
-            return false;
-    }
-    return true;
-}
-
-bool CurvesContainer::operator==(const CurvesContainer& other) const
-{
-    if (isEmpty() && other.isEmpty())
-        return true;
-
-    if (sixteenBit != other.sixteenBit || curvesType != other.curvesType)
-        return false;
-
-    for (int i=0; i<ColorChannels; i++)
-    {
-        if (values[i] != other.values[i])
-            return false;
-    }
-    return true;
-}
-
-void CurvesContainer::initialize()
-{
-    int segmentMax = sixteenBit ? MAX_SEGMENT_16BIT : MAX_SEGMENT_8BIT;
-
-    if (curvesType == ImageCurves::CURVE_FREE)
-    {
-        for (int i=0; i<ColorChannels; i++)
-        {
-            values[i].resize(segmentMax);
-
-            for (int j = 0 ; j <= segmentMax ; ++j)
-            {
-                values[i].setPoint(j, j, j);
-            }
-        }
-
-        // Construct linear curves.
-    }
-    else // SMOOTH
-    {
-        for (int i=0; i<ColorChannels; i++)
-        {
-            values[i].resize(ImageCurves::NUM_POINTS);
-
-            for (int j = 1 ; j < ImageCurves::NUM_POINTS - 1 ; ++j)
-            {
-                values[i].setPoint(j, -1, -1);
-            }
-
-            // First and last points init.
-            values[i].setPoint(0, 0, 0);
-            values[i].setPoint(0, segmentMax, segmentMax);
-        }
-    }
-}
-
-bool CurvesContainer::isStoredLosslessly() const
-{
-    return !(sixteenBit && curvesType == ImageCurves::CURVE_FREE);
-}
-
-void CurvesContainer::writeToFilterAction(FilterAction& action, const QString& prefix) const
-{
-    if (isEmpty())
-    {
-        return;
-    }
-
-    ImageCurves curves(*this);
-
-    if (curves.isLinear())
-    {
-        return;
-    }
-
-    // Convert to 8bit: 16 bits curves takes 85kb, 8 bits only 400 bytes.
-    if (curves.isSixteenBits())
-    {
-        ImageCurves depthCurve(false);
-        depthCurve.fillFromOtherCurves(&curves);
-        curves = depthCurve;
-    }
-
-    action.addParameter(prefix + "curveBitDepth", 8);
-
-    for (int i=0; i<ColorChannels; i++)
-    {
-        action.addParameter(prefix + QString("curveData[%1]").arg(i), curves.channelToBase64(i));
-    }
-}
-
-CurvesContainer CurvesContainer::fromFilterAction(const FilterAction& action, const QString& prefix)
-{
-    if (!action.hasParameter(prefix + "curveBitDepth"))
-    {
-        return CurvesContainer();
-    }
-
-    ImageCurves curves(action.parameter(prefix + "curveBitDepth", 8) == 16);
-
-    for (int i=0; i<ColorChannels; i++)
-    {
-        QByteArray base64 = action.parameter(prefix + QString("curveData[%1]").arg(i), QByteArray());
-        // check return value and set readParametersError?
-        curves.setChannelFromBase64(i, base64);
-    }
-
-    return curves.getContainer();
-}
-
 class ImageCurves::ImageCurvesPriv : public QSharedData
 {
 
@@ -291,7 +166,7 @@ ImageCurves::ImageCurves(const CurvesContainer& container)
 {
     d->init(container.sixteenBit);
     curvesReset();
-    setCurves(container);
+    setContainer(container);
 }
 
 ImageCurves::ImageCurves(const ImageCurves& other)
@@ -311,24 +186,40 @@ ImageCurves& ImageCurves::operator=(const ImageCurves& other)
 
 void ImageCurves::fillFromOtherCurves(ImageCurves* otherCurves)
 {
-
-    //kDebug() << "Filling this curve from other curve " << otherCurves;
+    kDebug() << "Filling this curve from other curve " << otherCurves;
 
     curvesReset();
 
     // if the other curves have the same bit depth, simply copy their data
     if (isSixteenBits() == otherCurves->isSixteenBits())
     {
-        //kDebug() << "Both curves have same type: isSixteenBits = " << isSixteenBits();
+        kDebug() << "Both curves have same type: isSixteenBits = " << isSixteenBits();
+
         for (int channel = 0; channel < NUM_CHANNELS; ++channel)
         {
-            for (int point = 0; point < NUM_POINTS; ++point)
+            if (otherCurves->getCurveType(channel) == CURVE_SMOOTH)
             {
-                QPoint p = otherCurves->getCurvePoint(channel, point);
+                kDebug() << "Other is CURVE_SMOOTH";
+                setCurveType(channel, CURVE_SMOOTH);
 
-                if (d->isPointEnabled(p))
+                for (int point = 0; point < NUM_POINTS; ++point)
                 {
-                    setCurvePoint(channel, point, p);
+                    QPoint p = otherCurves->getCurvePoint(channel, point);
+
+                    if (d->isPointEnabled(p))
+                    {
+                        setCurvePoint(channel, point, p);
+                    }
+                }
+            }
+            else
+            {
+                kDebug() << "Other is CURVE_FREE";
+                setCurveType(channel, CURVE_FREE);
+
+                for (int i = 0 ; i <= d->segmentMax ; ++i)
+                {
+                    setCurveValue(channel, i, otherCurves->getCurveValue(channel, i));
                 }
             }
         }
@@ -336,18 +227,35 @@ void ImageCurves::fillFromOtherCurves(ImageCurves* otherCurves)
     // other curve is 8 bit and this curve is 16 bit
     else if (isSixteenBits() && !otherCurves->isSixteenBits())
     {
-        //kDebug() << "This curve is 16 bit and the other is 8 bit";
+        kDebug() << "This curve is 16 bit and the other is 8 bit";
+
         for (int channel = 0; channel < NUM_CHANNELS; ++channel)
         {
-            for (int point = 0; point < NUM_POINTS; ++point)
+            if (otherCurves->getCurveType(channel) == CURVE_SMOOTH)
             {
-                QPoint p = otherCurves->getCurvePoint(channel, point);
+                kDebug() << "Other is CURVE_SMOOTH";
+                setCurveType(channel, CURVE_SMOOTH);
 
-                if (d->isPointEnabled(p))
+                for (int point = 0; point < NUM_POINTS; ++point)
                 {
-                    p.setX(p.x() * MULTIPLIER_16BIT);
-                    p.setY(p.y() * MULTIPLIER_16BIT);
-                    setCurvePoint(channel, point, p);
+                    QPoint p = otherCurves->getCurvePoint(channel, point);
+
+                    if (d->isPointEnabled(p))
+                    {
+                        p.setX(p.x() * MULTIPLIER_16BIT);
+                        p.setY(p.y() * MULTIPLIER_16BIT);
+                        setCurvePoint(channel, point, p);
+                    }
+                }
+            }
+            else
+            {
+                kDebug() << "Other is CURVE_FREE";
+                setCurveType(channel, CURVE_FREE);
+
+                for (int i = 0 ; i <= d->segmentMax ; ++i)
+                {
+                    setCurveValue(channel, i * MULTIPLIER_16BIT, otherCurves->getCurveValue(channel, i) * MULTIPLIER_16BIT);
                 }
             }
         }
@@ -355,25 +263,42 @@ void ImageCurves::fillFromOtherCurves(ImageCurves* otherCurves)
     // other curve is 16 bit and this is 8 bit
     else if (!isSixteenBits() && otherCurves->isSixteenBits())
     {
-        //kDebug() << "This curve is 8 bit and the other is 16 bit";
+        kDebug() << "This curve is 8 bit and the other is 16 bit";
+
         for (int channel = 0; channel < NUM_CHANNELS; ++channel)
         {
-            //kDebug() << "Adopting points of channel " << channel;
-            for (int point = 0; point < NUM_POINTS; ++point)
+            if (otherCurves->getCurveType(channel) == CURVE_SMOOTH)
             {
-                QPoint p = otherCurves->getCurvePoint(channel, point);
+                kDebug() << "Other is CURVE_SMOOTH";
+                setCurveType(channel, CURVE_SMOOTH);
 
-                //kDebug() << "Point " << point << " in original is " << p;
-                if (d->isPointEnabled(p))
+                //kDebug() << "Adopting points of channel " << channel;
+                for (int point = 0; point < NUM_POINTS; ++point)
                 {
-                    p.setX(p.x() / MULTIPLIER_16BIT);
-                    p.setY(p.y() / MULTIPLIER_16BIT);
-                    //kDebug() << "Setting curve point " << point << " to " << p;
-                    setCurvePoint(channel, point, p);
+                    QPoint p = otherCurves->getCurvePoint(channel, point);
+
+                    //kDebug() << "Point " << point << " in original is " << p;
+                    if (d->isPointEnabled(p))
+                    {
+                        p.setX(p.x() / MULTIPLIER_16BIT);
+                        p.setY(p.y() / MULTIPLIER_16BIT);
+                        //kDebug() << "Setting curve point " << point << " to " << p;
+                        setCurvePoint(channel, point, p);
+                    }
+                    else
+                    {
+                        //kDebug() << "ignoring this point";
+                    }
                 }
-                else
+            }
+            else
+            {
+                kDebug() << "Other is CURVE_FREE";
+                setCurveType(channel, CURVE_FREE);
+
+                for (int i = 0 ; i <= d->segmentMax ; ++i)
                 {
-                    //kDebug() << "ignoring this point";
+                    setCurveValue(channel, i / MULTIPLIER_16BIT, otherCurves->getCurveValue(channel, i) / MULTIPLIER_16BIT);
                 }
             }
         }
@@ -383,21 +308,8 @@ void ImageCurves::fillFromOtherCurves(ImageCurves* otherCurves)
         kError() << "Bad logic error, could not fill one curve into another";
     }
 
-    //kDebug() << "Updating curve types";
-
-    // adopt channel types
-    for (int channel = 0; channel < NUM_CHANNELS; ++channel)
-    {
-        //kDebug() << "Curve type for channel " << channel
-        //       << " is " << (int) otherCurves->getCurveType(channel);
-        setCurveType(channel, otherCurves->getCurveType(channel));
-    }
-
     // invoke calculations once
-    for (int channel = 0; channel < NUM_CHANNELS; ++channel)
-    {
-        curvesCalculateCurve(channel);
-    }
+    curvesCalculateAllCurves();
 }
 
 bool ImageCurves::isDirty() const
@@ -443,7 +355,7 @@ void ImageCurves::curvesChannelReset(int channel)
 
     // Init coordinates points to null.
 
-    for (j = 0 ; j < ImageCurves::NUM_POINTS ; ++j)
+    for (j = 0 ; j < NUM_POINTS ; ++j)
     {
         d->curves->points[channel][j][0] = -1;
         d->curves->points[channel][j][1] = -1;
@@ -725,10 +637,7 @@ void ImageCurves::curvesLutSetup(int nchannels)
     uint   v;
     double val;
 
-    for (i = 0 ; i < NUM_CHANNELS ; ++i)
-    {
-        curvesCalculateCurve(i);
-    }
+    curvesCalculateAllCurves();
 
     d->freeLutData();
 
@@ -972,18 +881,19 @@ ImageCurves::CurveType ImageCurves::getCurveType(int channel) const
 
 CurvesContainer ImageCurves::getContainer() const
 {
-    // any free curve?
     CurveType type = CURVE_SMOOTH;
 
-    for (int i=0; i<ColorChannels; i++)
+    for (int i = 0; i < ColorChannels; ++i)
     {
         if ( (type = getCurveType(i)) == CURVE_FREE)
         {
+            type = CURVE_FREE;
             break;
         }
     }
 
     CurvesContainer c(type, isSixteenBits());
+    c.initialize();
 
     if (isLinear())
     {
@@ -992,14 +902,14 @@ CurvesContainer ImageCurves::getContainer() const
 
     if (type == CURVE_FREE)
     {
-        for (int i=0; i<ColorChannels; i++)
+        for (int i = 0; i < ColorChannels; ++i)
         {
             c.values[i] = getCurveValues(i);
         }
     }
     else
     {
-        for (int i=0; i<ColorChannels; i++)
+        for (int i = 0; i < ColorChannels; ++i)
         {
             c.values[i] = getCurvePoints(i);
         }
@@ -1030,11 +940,11 @@ CurvesContainer ImageCurves::getContainer(int channel) const
     return c;
 }
 
-void ImageCurves::setCurves(const CurvesContainer& container)
+void ImageCurves::setContainer(const CurvesContainer& container)
 {
     if (container.curvesType == CURVE_FREE)
     {
-        for (int i=0; i<ColorChannels; i++)
+        for (int i = 0; i < ColorChannels; ++i)
         {
             setCurveType(i, CURVE_FREE);
             setCurveValues(i, container.values[i]);
@@ -1042,7 +952,7 @@ void ImageCurves::setCurves(const CurvesContainer& container)
     }
     else
     {
-        for (int i=0; i<ColorChannels; i++)
+        for (int i = 0; i < ColorChannels; ++i)
         {
             setCurveType(i, CURVE_SMOOTH);
             setCurvePoints(i, container.values[i]);
@@ -1064,11 +974,14 @@ void ImageCurves::setCurveValue(int channel, int bin, int val)
 void ImageCurves::setCurveValues(int channel, const QPolygon& vals)
 {
     int index;
+    kDebug() << "vals size: " << vals.size();
+    kDebug() << "segmentMax: " << d->segmentMax+1;
 
     if (d->curves && channel >= 0 && channel < NUM_CHANNELS)
     {
         if (vals.isEmpty())
         {
+            kDebug() << "No curves values to assign: reset";
             curvesChannelReset(channel);
         }
         // Bits depth are different ?
@@ -1076,6 +989,8 @@ void ImageCurves::setCurveValues(int channel, const QPolygon& vals)
         {
             if (vals.size() == 256)
             {
+                kDebug() << "8 to 16 bits curves transform";
+
                 // 8 to 16 bits.
                 ImageCurves curve8(false);
                 ImageCurves curve16(true);
@@ -1096,6 +1011,8 @@ void ImageCurves::setCurveValues(int channel, const QPolygon& vals)
             }
             else
             {
+                kDebug() << "16 to 8 bits curves transform";
+
                 // 16 to 8 bits.
                 ImageCurves curve8(false);
                 ImageCurves curve16(true);
@@ -1117,6 +1034,7 @@ void ImageCurves::setCurveValues(int channel, const QPolygon& vals)
         }
         else
         {
+            kDebug() << "Assign curves values directly";
             for (int j = 0 ; j <= d->segmentMax ; ++j)
             {
                 setCurveValue(channel, j, vals.point(j).y());
@@ -1283,15 +1201,20 @@ bool ImageCurves::loadCurvesFromGimpCurvesFile(const KUrl& fileUrl)
         }
     }
 
-    for (i = 0 ; i < NUM_CHANNELS ; ++i)
-    {
-        curvesCalculateCurve(i);
-    }
+    curvesCalculateAllCurves();
 
     fclose(file);
     return true;
 }
 
+void ImageCurves::curvesCalculateAllCurves()
+{
+    for (int i = 0 ; i < NUM_CHANNELS ; ++i)
+    {
+        curvesCalculateCurve(i);
+    }
+}
+
 bool ImageCurves::saveCurvesToGimpCurvesFile(const KUrl& fileUrl) const
 {
     // TODO : support KUrl !
@@ -1363,7 +1286,7 @@ bool ImageCurves::isLinear(int channel) const
 
     if (d->curves->curve_type[channel] == CURVE_FREE)
     {
-        for (int j=0; j<d->segmentMax; j++)
+        for (int j=0; j<d->segmentMax; ++j)
             if (d->curves->curve[channel][j] != j)
             {
                 return false;
@@ -1377,7 +1300,7 @@ bool ImageCurves::isLinear(int channel) const
         bool hasLast  = false;
 
         // find out number of valid points
-        for (int j=0; j<NUM_POINTS; j++)
+        for (int j=0; j<NUM_POINTS; ++j)
         {
             int x = d->curves->points[channel][j][0];
             int y = d->curves->points[channel][j][1];
@@ -1469,7 +1392,7 @@ QByteArray ImageCurves::channelToBase64(int channel) const
         quint32 count = 0;
 
         // find out number of valid points
-        for (int j=0; j<NUM_POINTS; j++)
+        for (int j=0; j<NUM_POINTS; ++j)
         {
             if (d->curves->points[channel][j][0] > -1 && d->curves->points[channel][j][1] > -1)
             {
@@ -1479,7 +1402,7 @@ QByteArray ImageCurves::channelToBase64(int channel) const
 
         s << (quint32)count; // number of stored points,
 
-        for (int j=0; j<NUM_POINTS; j++)
+        for (int j=0; j<NUM_POINTS; ++j)
         {
             if (d->curves->points[channel][j][0] > -1 && d->curves->points[channel][j][1] > -1)
             {
@@ -1494,14 +1417,14 @@ QByteArray ImageCurves::channelToBase64(int channel) const
 
         if (isSixteenBits())
         {
-            for (int j=0; j<d->segmentMax; j++)
+            for (int j=0; j<d->segmentMax; ++j)
             {
                 s << (quint16)d->curves->curve[channel][j];
             }
         }
         else
         {
-            for (int j=0; j<d->segmentMax; j++)
+            for (int j=0; j<d->segmentMax; ++j)
             {
                 s << (quint8)d->curves->curve[channel][j];
             }
@@ -1574,7 +1497,7 @@ bool ImageCurves::setChannelFromBase64(int channel, const QByteArray& array)
         QPolygon p(usedCount);
         quint32 x,y;
 
-        for (uint j=0; j<usedCount; j++)
+        for (uint j=0; j<usedCount; ++j)
         {
             s >> x;
             s >> y;
@@ -1596,7 +1519,7 @@ bool ImageCurves::setChannelFromBase64(int channel, const QByteArray& array)
         {
             quint16 data;
 
-            for (int j=0; j<d->segmentMax; j++)
+            for (int j=0; j<d->segmentMax; ++j)
             {
                 s >> data;
                 d->curves->curve[channel][j] = data;
@@ -1606,7 +1529,7 @@ bool ImageCurves::setChannelFromBase64(int channel, const QByteArray& array)
         {
             quint8 data;
 
-            for (int j=0; j<d->segmentMax; j++)
+            for (int j=0; j<d->segmentMax; ++j)
             {
                 s >> data;
                 d->curves->curve[channel][j] = data;
