@@ -69,8 +69,9 @@ public:
 
 Q_SIGNALS:
 
-    void signalProgressBarMode(int, const QString&);
-    void signalProgressValue(int);
+    void progressEntered(const QString&);
+    void progressValueChanged(float);
+    void progressFinished();
     void signalTagFilterMatch(bool);
     void signalPrevItem();
     void signalNextItem();
@@ -110,6 +111,7 @@ private Q_SLOTS:
     void slotTagsSearchChanged(const SearchTextSettings& settings);
     void slotTagStateChanged(Album* album, Qt::CheckState checkState);
     void slotCommentChanged();
+    void slotTitleChanged();
     void slotDateTimeChanged(const QDateTime& dateTime);
     void slotPickLabelChanged(int pickId);
     void slotColorLabelChanged(int colorId);
