@@ -960,8 +960,6 @@ void IconView::viewportPaintEvent(QPaintEvent* pe)
         }
     }
 
-    prepareRepaint(itemsToRepaint);
-
     foreach (IconItem* item, itemsToRepaint)
     {
         QRect viewportRect = contentsRectToViewport(item->rect());
@@ -977,11 +975,6 @@ void IconView::viewportPaintEvent(QPaintEvent* pe)
     painter.fillRect(pe->rect(), palette().color(QPalette::Base));
 }
 
-void IconView::prepareRepaint(const QList<IconItem*>& list)
-{
-    emit signalPrepareRepaint(list);
-}
-
 QRect IconView::contentsRectToViewport(const QRect& r) const
 {
     QRect vr = QRect(contentsToViewport(QPoint(r.x(), r.y())), r.size());
