@@ -184,17 +184,17 @@ DImgInterface::DImgInterface()
     d->undoMan = new UndoManager(this);
     d->thread  = new SharedLoadSaveThread;
 
-    connect( d->thread, SIGNAL(signalImageLoaded(const LoadingDescription&, const DImg&)),
-             this, SLOT(slotImageLoaded(const LoadingDescription&, const DImg&)) );
+    connect( d->thread, SIGNAL(signalImageLoaded(LoadingDescription,DImg)),
+             this, SLOT(slotImageLoaded(LoadingDescription,DImg)) );
 
-    connect( d->thread, SIGNAL(signalImageSaved(const QString&, bool)),
-             this, SLOT(slotImageSaved(const QString&, bool)) );
+    connect( d->thread, SIGNAL(signalImageSaved(QString,bool)),
+             this, SLOT(slotImageSaved(QString,bool)) );
 
-    connect( d->thread, SIGNAL(signalLoadingProgress(const LoadingDescription&, float)),
-             this, SLOT(slotLoadingProgress(const LoadingDescription&, float)) );
+    connect( d->thread, SIGNAL(signalLoadingProgress(LoadingDescription,float)),
+             this, SLOT(slotLoadingProgress(LoadingDescription,float)) );
 
-    connect( d->thread, SIGNAL(signalSavingProgress(const QString&, float)),
-             this, SLOT(slotSavingProgress(const QString&, float)) );
+    connect( d->thread, SIGNAL(signalSavingProgress(QString,float)),
+             this, SLOT(slotSavingProgress(QString,float)) );
 
     //readMetadataFromFile();
 }
@@ -508,30 +508,30 @@ void DImgInterface::undo()
 {
     if (!d->undoMan->anyMoreUndo())
     {
-        emit signalUndoStateChanged(false, d->undoMan->anyMoreRedo(), !d->undoMan->isAtOrigin());
+        emit signalUndoStateChanged();
         return;
     }
 
     d->undoMan->undo();
-    emit signalUndoStateChanged(d->undoMan->anyMoreUndo(), d->undoMan->anyMoreRedo(), !d->undoMan->isAtOrigin());
+    emit signalUndoStateChanged();
 }
 
 void DImgInterface::redo()
 {
     if (!d->undoMan->anyMoreRedo())
     {
-        emit signalUndoStateChanged(d->undoMan->anyMoreUndo(), false, !d->undoMan->isAtOrigin());
+        emit signalUndoStateChanged();
         return;
     }
 
     d->undoMan->redo();
-    emit signalUndoStateChanged(d->undoMan->anyMoreUndo(), d->undoMan->anyMoreRedo(), !d->undoMan->isAtOrigin());
+    emit signalUndoStateChanged();
 }
 
 void DImgInterface::rollbackToOrigin()
 {
     d->undoMan->rollbackToOrigin();
-    emit signalUndoStateChanged(d->undoMan->anyMoreUndo(), d->undoMan->anyMoreRedo(), !d->undoMan->isAtOrigin());
+    emit signalUndoStateChanged();
 }
 
 QMap<QString, QVariant> DImgInterface::ioAttributes(IOFileSettingsContainer* iofileSettings,
@@ -675,9 +675,9 @@ void DImgInterface::saveNext()
         d->undoMan->putImageDataAndHistory(&file.image, currentStep - file.historyStep);
     }
 
-    QMap<QString,QVariant>::iterator it;
+    QMap<QString,QVariant>::const_iterator it;
 
-    for (it = file.ioAttributes.begin(); it != file.ioAttributes.end(); ++it)
+    for (it = file.ioAttributes.constBegin(); it != file.ioAttributes.constEnd(); ++it)
     {
         file.image.setAttribute(it.key(), it.value());
     }
@@ -712,7 +712,7 @@ void DImgInterface::slotImageSaved(const QString& filePath, bool success)
             HistoryImageId id = savedFile.image.addAsReferredImage(filePath);
 
             // for all images following in history, we need to insert the now saved file at the right place
-            for (int i = d->currentFileToSave + 1; i < d->filesToSave.size(); i++)
+            for (int i = d->currentFileToSave + 1; i < d->filesToSave.size(); ++i)
             {
                 d->filesToSave[i].image.insertAsReferredImage(savedFile.historyStep, id);
             }
@@ -738,7 +738,7 @@ void DImgInterface::slotImageSaved(const QString& filePath, bool success)
 
 void DImgInterface::slotSavingProgress(const QString& filePath, float progress)
 {
-    if (!d->filesToSave.isEmpty() && d->filesToSave[d->currentFileToSave].filePath == filePath)
+    if (!d->filesToSave.isEmpty() && d->filesToSave.at(d->currentFileToSave).filePath == filePath)
     {
         emit signalSavingProgress(filePath, progress);
     }
@@ -749,7 +749,7 @@ void DImgInterface::abortSaving()
     // failure will be reported by a signal
     if (!d->filesToSave.isEmpty())
     {
-        d->thread->stopSaving(d->filesToSave[d->currentFileToSave].filePath);
+        d->thread->stopSaving(d->filesToSave.at(d->currentFileToSave).filePath);
         d->filesToSave.clear();
     }
 }
@@ -839,12 +839,24 @@ void DImgInterface::setHistoryIsBranch(bool isBranching)
 void DImgInterface::setModified()
 {
     emit signalModified();
-    emit signalUndoStateChanged(d->undoMan->anyMoreUndo(), d->undoMan->anyMoreRedo(), !d->undoMan->isAtOrigin());
+    emit signalUndoStateChanged();
 }
 
-bool DImgInterface::hasChangesToSave() const
+DImgInterface::UndoState::UndoState()
+    : hasUndo(false), hasRedo(false), hasChanges(false), hasUndoableChanges(false)
 {
-    return !d->undoMan->isAtOrigin();
+}
+
+DImgInterface::UndoState DImgInterface::undoState() const
+{
+    UndoState state;
+    state.hasUndo = d->undoMan->anyMoreUndo();
+    state.hasRedo = d->undoMan->anyMoreRedo();
+    state.hasUndoableChanges = !d->undoMan->isAtOrigin();
+    // Includes the edit step performed by RAW import, which is not undoable
+    state.hasChanges = d->undoMan->hasChanges();
+
+    return state;
 }
 
 void DImgInterface::readMetadataFromFile(const QString& file)
@@ -858,21 +870,16 @@ void DImgInterface::clearUndoManager()
 {
     d->undoMan->clear();
     d->undoMan->setOrigin();
-    emit signalUndoStateChanged(false, false, false);
+    emit signalUndoStateChanged();
 }
 
 void DImgInterface::setUndoManagerOrigin()
 {
     d->undoMan->setOrigin();
-    emit signalUndoStateChanged(d->undoMan->anyMoreUndo(), d->undoMan->anyMoreRedo(), !d->undoMan->isAtOrigin());
+    emit signalUndoStateChanged();
     emit signalFileOriginChanged(getImageFilePath());
 }
 
-void DImgInterface::updateUndoState()
-{
-    emit signalUndoStateChanged(d->undoMan->anyMoreUndo(), d->undoMan->anyMoreRedo(), !d->undoMan->isAtOrigin());
-}
-
 bool DImgInterface::imageValid() const
 {
     return d->valid;
