@@ -164,8 +164,8 @@ SetupMetadata::SetupMetadata(QWidget* parent)
                                            "You can set template values to Template setup page."));
 
     d->saveCommentsBox = new QCheckBox(commonGroup);
-    d->saveCommentsBox->setText(i18n("&Save image captions in metadata embedded in files "));
-    d->saveCommentsBox->setWhatsThis( i18n("Turn on this option to store image captions "
+    d->saveCommentsBox->setText(i18n("&Save image captions and title in metadata embedded in files "));
+    d->saveCommentsBox->setWhatsThis( i18n("Turn on this option to store image caption and title "
                                            "in the JFIF Comment section, the EXIF tag, the XMP tag, "
                                            "and the IPTC tag."));
 
@@ -371,8 +371,8 @@ SetupMetadata::SetupMetadata(QWidget* parent)
 
     readSettings();
 
-    connect(exiv2LogoLabel, SIGNAL(leftClickedUrl(const QString&)),
-            this, SLOT(slotProcessExiv2Url(const QString&)));
+    connect(exiv2LogoLabel, SIGNAL(leftClickedUrl(QString)),
+            this, SLOT(slotProcessExiv2Url(QString)));
 
     connect(d->exifRotateBox, SIGNAL(toggled(bool)),
             this, SLOT(slotExifAutoRotateToggled(bool)));
