@@ -101,11 +101,11 @@ void GalleryTalker::login(const KUrl& url, const QString& name, const QString& p
     m_job->addMetaData("content-type", form.contentType());
     m_job->addMetaData("cookies", "manual");
 
-    connect(m_job, SIGNAL(data(KIO::Job*, const QByteArray&)),
-            this, SLOT(slotTalkerData(KIO::Job*, const QByteArray&)));
+    connect(m_job, SIGNAL(data(KIO::Job*,QByteArray)),
+            this, SLOT(slotTalkerData(KIO::Job*,QByteArray)));
 
-    connect(m_job, SIGNAL(result(KJob *)),
-            this, SLOT(slotResult(KJob *)));
+    connect(m_job, SIGNAL(result(KJob*)),
+            this, SLOT(slotResult(KJob*)));
 
     emit signalBusy(true);
 }
@@ -129,11 +129,11 @@ void GalleryTalker::listAlbums()
     m_job->addMetaData("cookies", "manual");
     m_job->addMetaData("setcookies", m_cookie);
 
-    connect(m_job, SIGNAL(data(KIO::Job*, const QByteArray&)),
-            this, SLOT(slotTalkerData(KIO::Job*, const QByteArray&)));
+    connect(m_job, SIGNAL(data(KIO::Job*,QByteArray)),
+            this, SLOT(slotTalkerData(KIO::Job*,QByteArray)));
 
-    connect(m_job, SIGNAL(result(KJob *)),
-            this, SLOT(slotResult(KJob *)));
+    connect(m_job, SIGNAL(result(KJob*)),
+            this, SLOT(slotResult(KJob*)));
 
     emit signalBusy(true);
 }
@@ -155,11 +155,11 @@ void GalleryTalker::listPhotos(const QString& albumName)
     m_job->addMetaData("cookies", "manual");
     m_job->addMetaData("setcookies", m_cookie);
 
-    connect(m_job, SIGNAL(data(KIO::Job*, const QByteArray&)),
-            this, SLOT(slotTalkerData(KIO::Job*, const QByteArray&)));
+    connect(m_job, SIGNAL(data(KIO::Job*,QByteArray)),
+            this, SLOT(slotTalkerData(KIO::Job*,QByteArray)));
 
-    connect(m_job, SIGNAL(result(KJob *)),
-            this, SLOT(slotResult(KJob *)));
+    connect(m_job, SIGNAL(result(KJob*)),
+            this, SLOT(slotResult(KJob*)));
 
     emit signalBusy(true);
 }
@@ -194,8 +194,8 @@ void GalleryTalker::createAlbum(const QString& parentAlbumName,
     m_job->addMetaData("cookies", "manual");
     m_job->addMetaData("setcookies", m_cookie);
 
-    connect(m_job, SIGNAL(data(KIO::Job*, const QByteArray&)),
-            this, SLOT(slotTalkerData(KIO::Job*, const QByteArray&)));
+    connect(m_job, SIGNAL(data(KIO::Job*,QByteArray)),
+            this, SLOT(slotTalkerData(KIO::Job*,QByteArray)));
 
     connect(m_job, SIGNAL(result(KJob*)),
             this, SLOT(slotResult(KJob*)));
@@ -205,9 +205,8 @@ void GalleryTalker::createAlbum(const QString& parentAlbumName,
 
 bool GalleryTalker::addPhoto(const QString& albumName,
                              const QString& photoPath,
-                             const QString& caption,
-                             bool  captionIsTitle,
-                             bool  captionIsDescription,
+                             const QString& title,
+                             const QString& description,
                              bool  rescale,
                              int   maxDim)
 {
@@ -262,16 +261,13 @@ bool GalleryTalker::addPhoto(const QString& albumName,
     // The filename bit can perhaps be calculated in addFile()
     // but not sure of the temporary filename that could be
     // used for resizing... so I've added it explicitly for now.
-    if (!form.addFile(path, caption))
+    if (!form.addFile(path, title))
         return false;
 
-    if (!caption.isEmpty())
-    {
-        if (captionIsTitle)
-            form.addPair("caption", caption);
-        if (captionIsDescription)
-            form.addPair("extrafield.Description", caption);
-    }
+    if (!title.isEmpty())
+        form.addPair("caption", title);
+    if (!description.isEmpty())
+        form.addPair("extrafield.Description", description);
 
     form.finish();
 
@@ -280,11 +276,11 @@ bool GalleryTalker::addPhoto(const QString& albumName,
     m_job->addMetaData("cookies", "manual");
     m_job->addMetaData("setcookies", m_cookie);
 
-    connect(m_job, SIGNAL(data(KIO::Job*, const QByteArray&)),
-            this, SLOT(slotTalkerData(KIO::Job*, const QByteArray&)));
+    connect(m_job, SIGNAL(data(KIO::Job*,QByteArray)),
+            this, SLOT(slotTalkerData(KIO::Job*,QByteArray)));
 
-    connect(m_job, SIGNAL(result(KJob *)),
-            this, SLOT(slotResult(KJob *)));
+    connect(m_job, SIGNAL(result(KJob*)),
+            this, SLOT(slotResult(KJob*)));
 
     emit signalBusy(true);
 
