@@ -515,10 +515,10 @@ XMPOrigin::XMPOrigin(QWidget* parent)
 
     // --------------------------------------------------------
 
-    connect(d->dateCreatedSel, SIGNAL(valueChanged(const QDateTime&)),
+    connect(d->dateCreatedSel, SIGNAL(valueChanged(QDateTime)),
             this, SIGNAL(signalModified()));
 
-    connect(d->dateDigitalizedSel, SIGNAL(valueChanged(const QDateTime&)),
+    connect(d->dateDigitalizedSel, SIGNAL(valueChanged(QDateTime)),
             this, SIGNAL(signalModified()));
 
     // --------------------------------------------------------
@@ -534,13 +534,13 @@ XMPOrigin::XMPOrigin(QWidget* parent)
     connect(d->countryCB, SIGNAL(activated(int)),
             this, SIGNAL(signalModified()));
 
-    connect(d->cityEdit, SIGNAL(textChanged(const QString&)),
+    connect(d->cityEdit, SIGNAL(textChanged(QString)),
             this, SIGNAL(signalModified()));
 
-    connect(d->sublocationEdit, SIGNAL(textChanged(const QString&)),
+    connect(d->sublocationEdit, SIGNAL(textChanged(QString)),
             this, SIGNAL(signalModified()));
 
-    connect(d->provinceEdit, SIGNAL(textChanged(const QString&)),
+    connect(d->provinceEdit, SIGNAL(textChanged(QString)),
             this, SIGNAL(signalModified()));
 }
 
@@ -677,7 +677,7 @@ void XMPOrigin::readMetadata(QByteArray& xmpData)
     if (!data.isNull())
     {
         int item = -1;
-        for (int i = 0 ; i < d->countryCB->count() ; i++)
+        for (int i = 0 ; i < d->countryCB->count() ; ++i)
             if (d->countryCB->item(i).left(3) == data)
                 item = i;
 
